#include <stdio.h>

/**
*\file FonctionsResponsable.h
*\brief fichier.h qui contient les déclarations des fonctions concernant le responsable.
*\author BARDET Ange & Cyriaque SEGERIE
*\date 11 oct 2023
*/

/**
*\brief Demande l'article a ajouter ainsi que son poid, son volume et son prix a l'utilisateur et l'ajoute au fichier "articles.don".
*\param void Rien
*\return Rien
*/
void AjoutArticle(void);

/**
*\brief Demande un article au responsable puis modifie son poid, son volume et son prix dans les tables.
*\param[in] Tref tableau d'entier, réfèrences des produits.
*\param[in,out] Tpoid tableau d'entier, poids des produits.
*\param[in,out] Tvolume tableau d'entier, volumes des produits.
*\param[in,out] Tprix tableau d'entier, prix des produits.
*\param[in] n entier, taille logique des tableaux concernant les produits.
*\return Rien
*/
void ModifArticle(int Tref[], float Tpoid[],float Tvolume[],float Tprix[],int n);

/**
*\brief Récupère le contenu du fichier "articles.don" et l'ajoute au tables concernées (Tref,Tpoid,Tvolume,Tprix)
*\param[out] Tref tableau d'entier, réfèrences des produits.
*\param[out] Tpoid tableau d'entier, poids des produits.
*\param[out] Tvolume tableau d'entier, volumes des produits.
*\param[out] Tprix tableau d'entier, prix des produits.
*\return entier, taille logique des tableaux concernant les produits.
*/
int TableArticle(int Tref[], float Tpoid[],float Tvolume[],float Tprix[]);

/**
*\brief Affiche la référence, le poid, le volume et le prix de chaque produit.
*\param[in] Tref tableau d'entier, réfèrences des produits.
*\param[in] Tpoid tableau d'entier, poids des produits.
*\param[in] Tvolume tableau d'entier, volumes des produits.
*\param[in] Tprix tableau d'entier, prix des produits.
*\param[in] n entier, taille logique des tableaux concernant les produits.
*\return Rien
*/
void AffichTable(int Tref[], float Tpoid[],float Tvolume[],float Tprix[],int n);

/**
*\brief Demande un article au client puis affiche sa référence, son poid, son volume et son prix.
*\param[in] Tref tableau d'entier, réfèrences des produits.
*\param[in] Tpoid tableau d'entier, poids des produits.
*\param[in] Tvolume tableau d'entier, volumes des produits.
*\param[in] Tprix tableau d'entier, prix des produits.
*\param[in] n entier, taille logique des tableaux concernant les produits.
*\return Rien
*/
void AffichArticle(int Tref[], float Tpoid[],float Tvolume[],float Tprix[],int n);

/**
*\brief Demande un article au client puis le supprime des tables.
*\param[in,out] Tref tableau d'entier, réfèrences des produits.
*\param[out] Tpoid tableau d'entier, poids des produits.
*\param[out] Tvolume tableau d'entier, volumes des produits.
*\param[out] Tprix tableau d'entier, prix des produits.
*\param[in] n entier, taille logique des tableaux concernant les produits.
*\return entier, taille logique des tableaux concernant les produits - 1.
*/
int SupprArticle(int Tref[], float Tpoid[],float Tvolume[],float Tprix[],int n);

/**
*\brief Recherche la position de refR dans le tableau Tref.
*\param[in] Tref tableau d'entier, réfèrences des produits.
*\param[in] refR entier, réfèrence recherché dans le tableau référence.
*\param[in] n entier, taille logique des tableaux concernant les produits.
*\return entier, position de la réfèrence recherché.
*/
int posRef(int Tref[],int refR, int n);

/**
*\brief Ecrit dans le fichier "articles.don" le contenu des tables.
*\param[in] Tref tableau d'entier, réfèrences des produits.
*\param[in] Tpoid tableau d'entier, poids des produits.
*\param[in] Tvolume tableau d'entier, volumes des produits.
*\param[in] Tprix tableau d'entier, prix des produits.
*\param[in] n entier, taille logique des tableaux concernant les produits.
*\return rien.
*/
void EcrireFichier(int Tref[], float Tpoid[],float Tvolume[],float Tprix[],int n);


/**
*\brief Permet d'accéder à toutes les autres fonctions de cette partie.
*/
void modifclientglobal (void);

/**
*\brief Permet d'ajouter un client au fichier.
*\return Code d'erreur != 0 si un probléme se passe.
*/
int ajoutClient (void);

/**
*\brief Permet de suspendre la carte d'un client ou de la désuspendre (Et de créer un utilisateur si la carte se fais suspendre).
*\return Code d'erreur != 0 si un probléme se passe.
*\param[in] n Taille logique des tableaux.
*/
int suspensioncarte (int *n);

/**
*\brief Permet de compter le nombre de ligne d'un fichier et donc la taille logique des tableaux.
*\return Taille logique des tableaux.
*/
int compteurtaillelogique (void);

/**
*\brief Permet de supprimer la carte d'un client.
*\return Code d'erreur != 0 si un probléme se passe.
*\param[in] n Taille logique des tableaux.
*/
int supressionclient (int *n);

/**
*\brief Permet d'afficher les informations d'un client précis.
*\return Code d'erreur != 0 si un probléme se passe.
*/
int affichagesolo (void);

/**
*\brief Permet d'afficher tout le fichire client.
*\return Code d'erreur != 0 si un probléme se passe.
*/
int affichageall (void);

/**
*\brief Permet de vérifier la présence du fichier donnés , le crée si inexistant.
*\return Code d'erreur != 0 si un probléme se passe.
*/
int creationfichier(void);